@@ -17,21 +17,18 @@ if t.TYPE_CHECKING:
     from pytest_embedded_jtag import Gdb, OpenOcd
     from pytest_embedded_qemu import Qemu
     from pytest_embedded_serial import Serial
-    from pytest_embedded_wokwi import WokwiCLI
+    from pytest_embedded_wokwi import Wokwi
 
 from . import App, Dut
 from .log import MessageQueue, PexpectProcess
 from .utils import FIXTURES_SERVICES, ClassCliOptions, to_str
 
 
-def _drop_none_kwargs(kwargs: t.Dict[t.Any, t.Any]):
+def _drop_none_kwargs(kwargs: dict[t.Any, t.Any]):
     return {k: v for k, v in kwargs.items() if v is not None}
 
 
-if sys.platform == 'darwin':
-    _ctx = multiprocessing.get_context('fork')
-else:
-    _ctx = multiprocessing.get_context()
+_ctx = multiprocessing.get_context('spawn')
 
 _stdout = sys.__stdout__
 
@@ -45,10 +42,6 @@ DUT_GLOBAL_INDEX = 0
 PARAMETRIZED_FIXTURES_CACHE = {}
 
 
-def msg_queue_gn() -> MessageQueue:
-    return MessageQueue()
-
-
 def _listen(q: MessageQueue, filepath: str, with_timestamp: bool = True, count: int = 1, total: int = 1) -> None:
     shall_add_prefix = True
     while True:
@@ -145,9 +138,7 @@ def _fixture_classes_and_options_fn(
     qemu_prog_path,
     qemu_cli_args,
     qemu_extra_args,
-    wokwi_cli_path,
-    wokwi_timeout,
-    wokwi_scenario,
+    qemu_efuse_path,
     wokwi_diagram,
     skip_regenerate_image,
     encrypt,
@@ -161,9 +152,9 @@ def _fixture_classes_and_options_fn(
     _meta,
     **kwargs,
 ) -> ClassCliOptions:
-    classes: t.Dict[str, type] = {}
-    mixins: t.Dict[str, t.List[type]] = defaultdict(list)
-    kwargs: t.Dict[str, t.Dict[str, t.Any]] = defaultdict(dict)
+    classes: dict[str, type] = {}
+    mixins: dict[str, list[type]] = defaultdict(list)
+    kwargs: dict[str, dict[str, t.Any]] = defaultdict(dict)
 
     for fixture in FIXTURES_SERVICES.keys():
         if fixture == 'app':
@@ -182,6 +173,7 @@ def _fixture_classes_and_options_fn(
                             'encrypt': encrypt,
                             'keyfile': keyfile,
                             'qemu_prog_path': qemu_prog_path,
+                            'qemu_efuse_path': qemu_efuse_path,
                         }
                     )
                 else:
@@ -313,20 +305,18 @@ def _fixture_classes_and_options_fn(
                     'qemu_prog_path': qemu_prog_path,
                     'qemu_cli_args': qemu_cli_args,
                     'qemu_extra_args': qemu_extra_args,
+                    'qemu_efuse_path': qemu_efuse_path,
                     'app': None,
                     'meta': _meta,
                     'dut_index': dut_index,
                 }
         elif fixture == 'wokwi':
             if 'wokwi' in _services:
-                from pytest_embedded_wokwi import WokwiCLI
+                from pytest_embedded_wokwi import Wokwi
 
-                classes[fixture] = WokwiCLI
+                classes[fixture] = Wokwi
                 kwargs[fixture].update(
                     {
-                        'wokwi_cli_path': wokwi_cli_path,
-                        'wokwi_timeout': wokwi_timeout,
-                        'wokwi_scenario': wokwi_scenario,
                         'wokwi_diagram': wokwi_diagram,
                         'msg_queue': msg_queue,
                         'app': None,
@@ -455,7 +445,7 @@ def app_fn(_fixture_classes_and_options: ClassCliOptions) -> App:
     return cls(**_drop_none_kwargs(kwargs))
 
 
-def serial_gn(_fixture_classes_and_options, msg_queue, app) -> t.Optional[t.Union['Serial', 'LinuxSerial']]:
+def serial_gn(_fixture_classes_and_options, msg_queue, app) -> t.Union['Serial', 'LinuxSerial'] | None:
     if hasattr(app, 'target') and app.target == 'linux':
         from pytest_embedded_idf import LinuxSerial
 
@@ -523,7 +513,7 @@ def qemu_gn(_fixture_classes_and_options: ClassCliOptions, app) -> t.Optional['Q
     return cls(**_drop_none_kwargs(kwargs))
 
 
-def wokwi_gn(_fixture_classes_and_options: ClassCliOptions, app) -> t.Optional['WokwiCLI']:
+def wokwi_gn(_fixture_classes_and_options: ClassCliOptions, app) -> t.Optional['Wokwi']:
     """A wokwi subprocess that could read/redirect/write"""
     if 'wokwi' not in _fixture_classes_and_options.classes:
         return None
@@ -541,10 +531,10 @@ def dut_gn(
     openocd: t.Optional['OpenOcd'],
     gdb: t.Optional['Gdb'],
     app: App,
-    serial: t.Optional[t.Union['Serial', 'LinuxSerial']],
+    serial: t.Union['Serial', 'LinuxSerial'] | None,
     qemu: t.Optional['Qemu'],
-    wokwi: t.Optional['WokwiCLI'],
-) -> t.Union[Dut, t.List[Dut]]:
+    wokwi: t.Optional['Wokwi'],
+) -> Dut | list[Dut]:
     global DUT_GLOBAL_INDEX
     DUT_GLOBAL_INDEX += 1
 
@@ -578,7 +568,7 @@ def dut_gn(
     return cls(**_drop_none_kwargs(kwargs), mixins=mixins)
 
 
-def set_parametrized_fixtures_cache(values: t.Dict):
+def set_parametrized_fixtures_cache(values: dict):
     global PARAMETRIZED_FIXTURES_CACHE
     PARAMETRIZED_FIXTURES_CACHE = values.copy()
 
@@ -589,7 +579,7 @@ def _close_or_terminate(obj):
         return
 
     try:
-        if isinstance(obj, (subprocess.Popen, multiprocessing.process.BaseProcess)):
+        if isinstance(obj, subprocess.Popen | multiprocessing.process.BaseProcess):
             obj.terminate()
             obj.kill()
         elif isinstance(obj, io.IOBase):
@@ -632,7 +622,7 @@ class DutFactory:
     #    [openocd, gdb, serial, qemu, wokwi, dut]  # dut-1
     #    ...
     # ]
-    obj_stack: t.ClassVar[t.List[t.List[t.Any]]] = []
+    obj_stack: t.ClassVar[list[list[t.Any]]] = []
 
     @classmethod
     def close(cls):
@@ -661,39 +651,37 @@ class DutFactory:
         embedded_services: str = '',
         app_path: str = '',
         build_dir: str = 'build',
-        port: t.Optional[str] = None,
-        port_serial_number: t.Optional[str] = None,
-        port_location: t.Optional[str] = None,
-        port_mac: t.Optional[str] = None,
-        target: t.Optional[str] = None,
-        beta_target: t.Optional[str] = None,
-        baud: t.Optional[int] = None,
-        flash_port: t.Optional[str] = None,
-        skip_autoflash: t.Optional[bool] = None,
-        erase_all: t.Optional[bool] = None,
-        esptool_baud: t.Optional[int] = None,
-        esp_flash_force: t.Optional[bool] = False,
-        part_tool: t.Optional[str] = None,
-        confirm_target_elf_sha256: t.Optional[bool] = None,
-        erase_nvs: t.Optional[bool] = None,
-        skip_check_coredump: t.Optional[bool] = None,
-        panic_output_decode_script: t.Optional[str] = None,
-        openocd_prog_path: t.Optional[str] = None,
-        openocd_cli_args: t.Optional[str] = None,
-        gdb_prog_path: t.Optional[str] = None,
-        gdb_cli_args: t.Optional[str] = None,
-        no_gdb: t.Optional[bool] = None,
-        qemu_image_path: t.Optional[str] = None,
-        qemu_prog_path: t.Optional[str] = None,
-        qemu_cli_args: t.Optional[str] = None,
-        qemu_extra_args: t.Optional[str] = None,
-        wokwi_cli_path: t.Optional[str] = None,
-        wokwi_timeout: t.Optional[int] = 0,
-        wokwi_scenario: t.Optional[str] = None,
-        wokwi_diagram: t.Optional[str] = None,
-        skip_regenerate_image: t.Optional[bool] = None,
-        encrypt: t.Optional[bool] = None,
-        keyfile: t.Optional[str] = None,
+        port: str | None = None,
+        port_serial_number: str | None = None,
+        port_location: str | None = None,
+        port_mac: str | None = None,
+        target: str | None = None,
+        beta_target: str | None = None,
+        baud: int | None = None,
+        flash_port: str | None = None,
+        skip_autoflash: bool | None = None,
+        erase_all: bool | None = None,
+        esptool_baud: int | None = None,
+        esp_flash_force: bool | None = False,
+        part_tool: str | None = None,
+        confirm_target_elf_sha256: bool | None = None,
+        erase_nvs: bool | None = None,
+        skip_check_coredump: bool | None = None,
+        panic_output_decode_script: str | None = None,
+        openocd_prog_path: str | None = None,
+        openocd_cli_args: str | None = None,
+        gdb_prog_path: str | None = None,
+        gdb_cli_args: str | None = None,
+        no_gdb: bool | None = None,
+        qemu_image_path: str | None = None,
+        qemu_prog_path: str | None = None,
+        qemu_cli_args: str | None = None,
+        qemu_extra_args: str | None = None,
+        qemu_efuse_path: str | None = None,
+        wokwi_diagram: str | None = None,
+        skip_regenerate_image: bool | None = None,
+        encrypt: bool | None = None,
+        keyfile: str | None = None,
     ):
         """
         Create a Device Under Test (DUT) object with customizable parameters.
@@ -736,9 +724,7 @@ class DutFactory:
             qemu_prog_path: QEMU program path.
             qemu_cli_args: QEMU CLI arguments.
             qemu_extra_args: Additional QEMU arguments.
-            wokwi_cli_path: Wokwi CLI path.
-            wokwi_timeout: Wokwi timeout.
-            wokwi_scenario: Wokwi scenario path.
+            qemu_efuse_path: Efuse binary path.
             wokwi_diagram: Wokwi diagram path.
             skip_regenerate_image: Skip image regeneration flag.
             encrypt: Encryption flag.
@@ -753,10 +739,15 @@ class DutFactory:
         """
         layout = []
         try:
-            global PARAMETRIZED_FIXTURES_CACHE
-            msg_queue = msg_queue_gn()
+            from .plugin import _MP_MANAGER  # avoid circular import
+
+            if _MP_MANAGER is None:
+                raise SystemExit('The _MP_MANAGER is not initialized, please use this function under pytest.')
+
+            msg_queue = _MP_MANAGER.MessageQueue()
             layout.append(msg_queue)
 
+            global PARAMETRIZED_FIXTURES_CACHE
             _pexpect_logfile = os.path.join(
                 PARAMETRIZED_FIXTURES_CACHE['_meta'].logdir, f'custom-dut-{DUT_GLOBAL_INDEX}.txt'
             )
@@ -801,9 +792,7 @@ class DutFactory:
                 'qemu_prog_path': qemu_prog_path,
                 'qemu_cli_args': qemu_cli_args,
                 'qemu_extra_args': qemu_extra_args,
-                'wokwi_cli_path': wokwi_cli_path,
-                'wokwi_timeout': wokwi_timeout,
-                'wokwi_scenario': wokwi_scenario,
+                'qemu_efuse_path': qemu_efuse_path,
                 'wokwi_diagram': wokwi_diagram,
                 'skip_regenerate_image': skip_regenerate_image,
                 'encrypt': encrypt,
@@ -849,16 +838,3 @@ class DutFactory:
                 _close_or_terminate(obj)
             del layout
             raise e
-
-    @classmethod
-    def get_all_duts(cls) -> list[Dut]:
-        """Get all DUTs created by DutFactory."""
-
-        duts = []
-        for layout in cls.obj_stack:
-            # The DUT is always the last object in the layout
-            dut = layout[-1]
-            if isinstance(dut, Dut):
-                duts.append(dut)
-
-        return duts
