@@ -3,12 +3,12 @@ import logging
 import multiprocessing
 import os
 import subprocess
-import sys
 import tempfile
 import textwrap
 import uuid
 from multiprocessing import queues
-from typing import AnyStr, List, Optional, Union
+from multiprocessing.managers import BaseManager
+from typing import AnyStr
 
 import pexpect.fdpexpect
 from pexpect import EOF, TIMEOUT
@@ -16,10 +16,11 @@ from pexpect.utils import poll_ignore_interrupts, select_ignore_interrupts
 
 from .utils import Meta, remove_asci_color_code, to_bytes, to_str, utcnow_str
 
-if sys.platform == 'darwin':
-    _ctx = multiprocessing.get_context('fork')
-else:
-    _ctx = multiprocessing.get_context()
+_ctx = multiprocessing.get_context('spawn')
+
+
+class MessageQueueManager(BaseManager):
+    pass
 
 
 class MessageQueue(queues.Queue):
@@ -30,7 +31,7 @@ class MessageQueue(queues.Queue):
         super().__init__(*args, **kwargs)
 
     def put(self, obj, **kwargs):
-        if not isinstance(obj, (str, bytes)):
+        if not isinstance(obj, str | bytes):
             super().put(obj, **kwargs)
             return
 
@@ -40,7 +41,7 @@ class MessageQueue(queues.Queue):
         _b = to_bytes(obj)
         try:
             super().put(_b, **kwargs)
-        except:  # noqa # queue might be closed
+        except Exception:  # queue might be closed
             pass
 
     def write(self, s: AnyStr):
@@ -53,6 +54,9 @@ class MessageQueue(queues.Queue):
         return True
 
 
+MessageQueueManager.register('MessageQueue', MessageQueue)
+
+
 class PexpectProcess(pexpect.fdpexpect.fdspawn):
     """
     Use a temp file to gather multiple inputs into one output, and do `pexpect.expect()` from one place.
@@ -116,7 +120,7 @@ class PexpectProcess(pexpect.fdpexpect.fdspawn):
         self.close()
 
 
-def live_print_call(*args, msg_queue: Optional[MessageQueue] = None, expect_returncode: int = 0, **kwargs):
+def live_print_call(*args, msg_queue: MessageQueue | None = None, expect_returncode: int = 0, **kwargs):
     """
     live print the `subprocess.Popen` process
 
@@ -146,16 +150,16 @@ def live_print_call(*args, msg_queue: Optional[MessageQueue] = None, expect_retu
 
 class _PopenRedirectProcess(_ctx.Process):
     def __init__(self, msg_queue: MessageQueue, logfile: str):
-        self._q = msg_queue
+        super().__init__(target=self._forward_io, args=(msg_queue, logfile), daemon=True)
 
-        self.logfile = logfile
-
-        super().__init__(target=self._forward_io, daemon=True)  # killed by the main process
-
-    def _forward_io(self) -> None:
-        with open(self.logfile) as fr:
+    @staticmethod
+    def _forward_io(msg_queue, logfile) -> None:
+        with open(logfile) as fr:
             while True:
-                self._q.put(fr.read())
+                try:
+                    msg_queue.put(fr.read())  # msg_queue may be closed
+                except Exception:
+                    break
 
 
 class DuplicateStdoutPopen(subprocess.Popen):
@@ -166,7 +170,7 @@ class DuplicateStdoutPopen(subprocess.Popen):
     SOURCE = 'POPEN'
     REDIRECT_CLS = _PopenRedirectProcess
 
-    def __init__(self, msg_queue: MessageQueue, cmd: Union[str, List[str]], meta: Optional[Meta] = None, **kwargs):
+    def __init__(self, msg_queue: MessageQueue, cmd: str | list[str] = [], meta: Meta | None = None, **kwargs):
         self._q = msg_queue
         self._p = None
 
@@ -188,18 +192,30 @@ class DuplicateStdoutPopen(subprocess.Popen):
         self._logfile_offset = 0
         logging.debug(f'temp log file: {_log_file}')
 
-        kwargs.update(
-            {
-                'bufsize': 0,
-                'stdin': subprocess.PIPE,
-                'stdout': self._fw,
-                'stderr': self._fw,
-            }
-        )
-
         self._cmd = cmd
-        logging.info('Executing %s', ' '.join(cmd) if isinstance(cmd, list) else cmd)
-        super().__init__(cmd, **kwargs)
+
+        # Only start subprocess if command is not empty
+        if cmd and cmd != []:
+            kwargs.update(
+                {
+                    'bufsize': 0,
+                    'stdin': subprocess.PIPE,
+                    'stdout': self._fw,
+                    'stderr': self._fw,
+                }
+            )
+
+            logging.info('Executing %s', ' '.join(cmd) if isinstance(cmd, list) else cmd)
+            super().__init__(cmd, **kwargs)
+        else:
+            # For empty commands, initialize minimal subprocess.Popen attributes
+            logging.debug('Empty command provided, not starting subprocess')
+            self.args = cmd
+            self.returncode = None
+            self.pid = None
+            self.stdin = None
+            self.stdout = None
+            self.stderr = None
 
         # some sub classes does not need to redirect to the message queue, they use blocking-IO instead and
         # return the response immediately in `write()`
