@@ -36,7 +36,6 @@ from .dut_factory import (
     app_fn,
     dut_gn,
     gdb_gn,
-    msg_queue_gn,
     openocd_gn,
     pexpect_proc_fn,
     qemu_gn,
@@ -44,7 +43,7 @@ from .dut_factory import (
     set_parametrized_fixtures_cache,
     wokwi_gn,
 )
-from .log import MessageQueue, PexpectProcess
+from .log import MessageQueue, MessageQueueManager, PexpectProcess
 from .unity import JunitMerger, UnityTestReportMode, escape_illegal_xml_chars
 from .utils import (
     SERVICE_LIB_NAMES,
@@ -63,7 +62,7 @@ if t.TYPE_CHECKING:
     from pytest_embedded_jtag import Gdb, OpenOcd
     from pytest_embedded_qemu import Qemu
     from pytest_embedded_serial import Serial
-    from pytest_embedded_wokwi import WokwiCLI
+    from pytest_embedded_wokwi import Wokwi
 
 
 _T = t.TypeVar('_T')
@@ -168,13 +167,6 @@ def pytest_addoption(parser):
     esp_group = parser.getgroup('embedded-esp')
     esp_group.addoption('--target', help='serial target chip type. (Default: "auto")')
     esp_group.addoption('--beta-target', help='serial target beta version chip type. (Default: same as [--target])')
-    esp_group.addoption(
-        '--add-target-as-marker',
-        help='[DEPRECATED, use --add-target-as-marker-with-amount instead] '
-        'add target param as a function marker. Useful in CI with runners with different tags.'
-        'y/yes/true for True and n/no/false for False. '
-        '(Default: False, parametrization not supported, `|` will be escaped to `-`)',
-    )
     esp_group.addoption(
         '--add-target-as-marker-with-amount',
         help='add target param as a function marker with the amount of the target. Useful in CI with runners with '
@@ -282,6 +274,10 @@ def pytest_addoption(parser):
         '--qemu-extra-args',
         help='QEMU cli extra arguments, will append to the argument list. (Default: None)',
     )
+    qemu_group.addoption(
+        '--qemu-efuse-path',
+        help='This option makes it possible to use efuse in QEMU when it is set up.',
+    )
     qemu_group.addoption(
         '--skip-regenerate-image',
         help='y/yes/true for True and n/no/false for False. '
@@ -297,20 +293,6 @@ def pytest_addoption(parser):
     )
 
     wokwi_group = parser.getgroup('embedded-wokwi')
-    wokwi_group.addoption(
-        '--wokwi-cli-path',
-        help='Path to the wokwi-cli program (Default: "wokwi-cli")',
-    )
-    wokwi_group.addoption(
-        '--wokwi-timeout',
-        default=86400000,
-        type=_gte_one_int,
-        help='Simulation timeout in milliseconds (Default: 86400000)',
-    )
-    wokwi_group.addoption(
-        '--wokwi-scenario',
-        help='Path to the wokwi scenario file (Default: None)',
-    )
     wokwi_group.addoption(
         '--wokwi-diagram',
         help='Path to the wokwi diagram file (Default: None)',
@@ -321,6 +303,7 @@ def pytest_addoption(parser):
 # helpers #
 ###########
 _COUNT = 1
+_MP_MANAGER: MessageQueueManager | None = None
 
 
 def _gte_one_int(v) -> int:
@@ -335,7 +318,7 @@ def _gte_one_int(v) -> int:
     raise argparse.ArgumentTypeError('should be a integer greater or equal to 1')
 
 
-def _str_bool(v: str) -> t.Union[bool, str, None]:
+def _str_bool(v: str) -> bool | str | None:
     if v is None:
         return None
 
@@ -363,7 +346,7 @@ def count(request):
     _COUNT = _gte_one_int(getattr(request, 'param', request.config.option.count))
 
 
-def parse_multi_dut_args(count: int, s: str) -> t.Union[t.Any, t.Tuple[t.Any]]:
+def parse_multi_dut_args(count: int, s: str) -> t.Any | tuple[t.Any]:
     """
     Parse multi-dut argument by the following rules:
 
@@ -399,7 +382,7 @@ def parse_multi_dut_args(count: int, s: str) -> t.Union[t.Any, t.Tuple[t.Any]]:
             return tuple(_str_bool(item) for item in res)
 
 
-def multi_dut_argument(func) -> t.Callable[..., t.Union[t.Optional[str], t.Tuple[t.Optional[str]]]]:
+def multi_dut_argument(func) -> t.Callable[..., str | None | tuple[str | None]]:
     """
     Used for parse the multi-dut argument according to the `count` amount.
     """
@@ -411,7 +394,7 @@ def multi_dut_argument(func) -> t.Callable[..., t.Union[t.Optional[str], t.Tuple
     return wrapper
 
 
-def multi_dut_fixture(func) -> t.Callable[..., t.Union[t.Any, t.Tuple[t.Any]]]:
+def multi_dut_fixture(func) -> t.Callable[..., t.Any | tuple[t.Any]]:
     """
     Apply the multi-dut arguments to each fixture.
 
@@ -457,7 +440,7 @@ def multi_dut_fixture(func) -> t.Callable[..., t.Union[t.Any, t.Tuple[t.Any]]]:
 
 def multi_dut_generator_fixture(
     func,
-) -> t.Callable[..., t.Generator[t.Union[t.Any, t.Tuple[t.Any]], t.Any, None]]:
+) -> t.Callable[..., t.Generator[t.Any | tuple[t.Any], t.Any, None]]:
     """
     Apply the multi-dut arguments to each fixture.
 
@@ -478,7 +461,7 @@ def multi_dut_generator_fixture(
                 return
 
             try:
-                if isinstance(obj, (subprocess.Popen, multiprocessing.process.BaseProcess)):
+                if isinstance(obj, subprocess.Popen | multiprocessing.process.BaseProcess):
                     obj.terminate()
                     obj.kill()
                 elif isinstance(obj, io.IOBase):
@@ -626,11 +609,11 @@ def cache_dir(request: FixtureRequest) -> str:
 
 
 @pytest.fixture(scope='session')
-def port_target_cache(cache_dir) -> t.Dict[str, str]:
+def port_target_cache(cache_dir) -> dict[str, str]:
     """Session scoped port-target cache, for esp only"""
     _cache_file_path = os.path.join(cache_dir, 'port_target_cache')
     lock = filelock.FileLock(f'{_cache_file_path}.lock')
-    resp: t.Dict[str, str] = {}
+    resp: dict[str, str] = {}
     with lock:
         try:
             with shelve.open(_cache_file_path) as f:
@@ -646,11 +629,24 @@ def port_target_cache(cache_dir) -> t.Dict[str, str]:
 
 
 @pytest.fixture(scope='session')
-def port_app_cache() -> t.Dict[str, str]:
+def port_app_cache() -> dict[str, str]:
     """Session scoped port-app cache, for idf only"""
     return {}
 
 
+@pytest.fixture(scope='session', autouse=True)
+def _mp_manager():
+    manager = MessageQueueManager()
+    manager.start()
+
+    global _MP_MANAGER
+    _MP_MANAGER = manager
+
+    yield manager
+
+    manager.shutdown()
+
+
 @pytest.fixture
 def test_case_tempdir(test_case_name: str, session_tempdir: str) -> str:
     """Function scoped temp dir for pytest-embedded"""
@@ -689,8 +685,8 @@ def _pexpect_logfile(test_case_tempdir, logfile_extension, dut_index, dut_total)
 
 @pytest.fixture
 @multi_dut_generator_fixture
-def msg_queue() -> MessageQueue:  # kwargs passed by `multi_dut_generator_fixture()`
-    return msg_queue_gn()
+def msg_queue(_mp_manager) -> MessageQueue:  # kwargs passed by `multi_dut_generator_fixture()`
+    return _mp_manager.MessageQueue()
 
 
 @pytest.fixture
@@ -754,14 +750,14 @@ def redirect(msg_queue: MessageQueue) -> t.Callable[..., contextlib.redirect_std
 ########
 @pytest.fixture
 @multi_dut_argument
-def embedded_services(request: FixtureRequest) -> t.Optional[str]:
+def embedded_services(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'embedded_services', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def app_path(request: FixtureRequest, test_file_path: str, record_xml_attribute) -> t.Optional[str]:
+def app_path(request: FixtureRequest, test_file_path: str, record_xml_attribute) -> str | None:
     """Enable parametrization for the same cli option"""
     res = _request_param_or_config_option_or_default(request, 'app_path', os.path.dirname(test_file_path))
     record_xml_attribute('app_path', res)
@@ -770,14 +766,14 @@ def app_path(request: FixtureRequest, test_file_path: str, record_xml_attribute)
 
 @pytest.fixture
 @multi_dut_argument
-def esp_flash_force(request: FixtureRequest) -> t.Optional[str]:
+def esp_flash_force(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'esp_flash_force', False)
 
 
 @pytest.fixture
 @multi_dut_argument
-def build_dir(request: FixtureRequest) -> t.Optional[str]:
+def build_dir(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'build_dir', 'build')
 
@@ -787,21 +783,21 @@ def build_dir(request: FixtureRequest) -> t.Optional[str]:
 ##########
 @pytest.fixture
 @multi_dut_argument
-def port(request: FixtureRequest) -> t.Optional[str]:
+def port(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'port', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def baud(request: FixtureRequest) -> t.Optional[str]:
+def baud(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'baud', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def port_location(request: FixtureRequest) -> t.Optional[str]:
+def port_location(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'port_location', None)
 
@@ -811,56 +807,56 @@ def port_location(request: FixtureRequest) -> t.Optional[str]:
 #######
 @pytest.fixture
 @multi_dut_argument
-def target(request: FixtureRequest) -> t.Optional[str]:
+def target(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'target', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def beta_target(request: FixtureRequest) -> t.Optional[str]:
+def beta_target(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'beta_target', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def flash_port(request: FixtureRequest) -> t.Optional[str]:
+def flash_port(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'flash_port', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def skip_autoflash(request: FixtureRequest) -> t.Optional[bool]:
+def skip_autoflash(request: FixtureRequest) -> bool | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'skip_autoflash', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def erase_all(request: FixtureRequest) -> t.Optional[bool]:
+def erase_all(request: FixtureRequest) -> bool | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'erase_all', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def esptool_baud(request: FixtureRequest) -> t.Optional[str]:
+def esptool_baud(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'esptool_baud', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def port_mac(request: FixtureRequest) -> t.Optional[str]:
+def port_mac(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'port_mac', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def port_serial_number(request: FixtureRequest) -> t.Optional[str]:
+def port_serial_number(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'port_serial_number', None)
 
@@ -870,35 +866,35 @@ def port_serial_number(request: FixtureRequest) -> t.Optional[str]:
 #######
 @pytest.fixture
 @multi_dut_argument
-def part_tool(request: FixtureRequest) -> t.Optional[str]:
+def part_tool(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'part_tool', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def confirm_target_elf_sha256(request: FixtureRequest) -> t.Optional[bool]:
+def confirm_target_elf_sha256(request: FixtureRequest) -> bool | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'confirm_target_elf_sha256', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def erase_nvs(request: FixtureRequest) -> t.Optional[bool]:
+def erase_nvs(request: FixtureRequest) -> bool | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'erase_nvs', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def skip_check_coredump(request: FixtureRequest) -> t.Optional[bool]:
+def skip_check_coredump(request: FixtureRequest) -> bool | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'skip_check_coredump', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def panic_output_decode_script(request: FixtureRequest) -> t.Optional[bool]:
+def panic_output_decode_script(request: FixtureRequest) -> bool | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'panic_output_decode_script', None)
 
@@ -908,14 +904,14 @@ def panic_output_decode_script(request: FixtureRequest) -> t.Optional[bool]:
 ########
 @pytest.fixture
 @multi_dut_argument
-def gdb_prog_path(request: FixtureRequest) -> t.Optional[str]:
+def gdb_prog_path(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'gdb_prog_path', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def gdb_cli_args(request: FixtureRequest) -> t.Optional[str]:
+def gdb_cli_args(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'gdb_cli_args', None)
 
@@ -928,14 +924,14 @@ def no_gdb(request: FixtureRequest) -> bool:
 
 @pytest.fixture
 @multi_dut_argument
-def openocd_prog_path(request: FixtureRequest) -> t.Optional[str]:
+def openocd_prog_path(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'openocd_prog_path', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def openocd_cli_args(request: FixtureRequest) -> t.Optional[str]:
+def openocd_cli_args(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'openocd_cli_args', None)
 
@@ -945,49 +941,56 @@ def openocd_cli_args(request: FixtureRequest) -> t.Optional[str]:
 ########
 @pytest.fixture
 @multi_dut_argument
-def qemu_image_path(request: FixtureRequest) -> t.Optional[str]:
+def qemu_image_path(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'qemu_image_path', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def qemu_prog_path(request: FixtureRequest) -> t.Optional[str]:
+def qemu_prog_path(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'qemu_prog_path', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def qemu_cli_args(request: FixtureRequest) -> t.Optional[str]:
+def qemu_cli_args(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'qemu_cli_args', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def qemu_extra_args(request: FixtureRequest) -> t.Optional[str]:
+def qemu_extra_args(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'qemu_extra_args', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def skip_regenerate_image(request: FixtureRequest) -> t.Optional[str]:
+def qemu_efuse_path(request: FixtureRequest) -> str | None:
+    """Enable parametrization for the same cli option"""
+    return _request_param_or_config_option_or_default(request, 'qemu_efuse_path', None)
+
+
+@pytest.fixture
+@multi_dut_argument
+def skip_regenerate_image(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'skip_regenerate_image', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def encrypt(request: FixtureRequest) -> t.Optional[str]:
+def encrypt(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'encrypt', None)
 
 
 @pytest.fixture
 @multi_dut_argument
-def keyfile(request: FixtureRequest) -> t.Optional[str]:
+def keyfile(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'keyfile', None)
 
@@ -997,28 +1000,7 @@ def keyfile(request: FixtureRequest) -> t.Optional[str]:
 #########
 @pytest.fixture
 @multi_dut_argument
-def wokwi_cli_path(request: FixtureRequest) -> t.Optional[str]:
-    """Enable parametrization for the same cli option"""
-    return _request_param_or_config_option_or_default(request, 'wokwi_cli_path', None)
-
-
-@pytest.fixture
-@multi_dut_argument
-def wokwi_timeout(request: FixtureRequest) -> t.Optional[str]:
-    """Enable parametrization for the same cli option"""
-    return _request_param_or_config_option_or_default(request, 'wokwi_timeout', None)
-
-
-@pytest.fixture
-@multi_dut_argument
-def wokwi_scenario(request: FixtureRequest) -> t.Optional[str]:
-    """Enable parametrization for the same cli option"""
-    return _request_param_or_config_option_or_default(request, 'wokwi_scenario', None)
-
-
-@pytest.fixture
-@multi_dut_argument
-def wokwi_diagram(request: FixtureRequest) -> t.Optional[str]:
+def wokwi_diagram(request: FixtureRequest) -> str | None:
     """Enable parametrization for the same cli option"""
     return _request_param_or_config_option_or_default(request, 'wokwi_diagram', None)
 
@@ -1028,7 +1010,7 @@ def wokwi_diagram(request: FixtureRequest) -> t.Optional[str]:
 ####################
 @pytest.fixture
 @multi_dut_fixture
-def _services(embedded_services: t.Optional[str]) -> t.List[str]:
+def _services(embedded_services: str | None) -> list[str]:
     if not embedded_services:
         return ['base']
 
@@ -1079,9 +1061,7 @@ def parametrize_fixtures(
     qemu_prog_path,
     qemu_cli_args,
     qemu_extra_args,
-    wokwi_cli_path,
-    wokwi_timeout,
-    wokwi_scenario,
+    qemu_efuse_path,
     wokwi_diagram,
     skip_regenerate_image,
     encrypt,
@@ -1146,7 +1126,7 @@ def app(_fixture_classes_and_options: ClassCliOptions) -> App:
 
 @pytest.fixture
 @multi_dut_generator_fixture
-def serial(_fixture_classes_and_options, msg_queue, app) -> t.Optional[t.Union['Serial', 'LinuxSerial']]:
+def serial(_fixture_classes_and_options, msg_queue, app) -> t.Union['Serial', 'LinuxSerial'] | None:
     """A serial subprocess that could read/redirect/write"""
     return serial_gn(**locals())
 
@@ -1174,7 +1154,7 @@ def qemu(_fixture_classes_and_options: ClassCliOptions, app) -> t.Optional['Qemu
 
 @pytest.fixture
 @multi_dut_generator_fixture
-def wokwi(_fixture_classes_and_options: ClassCliOptions, app) -> t.Optional['WokwiCLI']:
+def wokwi(_fixture_classes_and_options: ClassCliOptions, app) -> t.Optional['Wokwi']:
     """A wokwi subprocess that could read/redirect/write"""
     return wokwi_gn(**locals())
 
@@ -1186,10 +1166,10 @@ def dut(
     openocd: t.Optional['OpenOcd'],
     gdb: t.Optional['Gdb'],
     app: App,
-    serial: t.Optional[t.Union['Serial', 'LinuxSerial']],
+    serial: t.Union['Serial', 'LinuxSerial'] | None,
     qemu: t.Optional['Qemu'],
-    wokwi: t.Optional['WokwiCLI'],
-) -> t.Union[Dut, t.List[Dut]]:
+    wokwi: t.Optional['Wokwi'],
+) -> Dut | list[Dut]:
     """
     A device under test (DUT) object that could gather output from various sources and redirect them to the pexpect
     process, and run `expect()` via its pexpect process.
@@ -1198,7 +1178,7 @@ def dut(
 
 
 @pytest.fixture
-def unity_tester(dut: t.Union['IdfDut', t.Tuple['IdfDut']]) -> t.Optional['CaseTester']:
+def unity_tester(dut: t.Union['IdfDut', tuple['IdfDut']]) -> t.Optional['CaseTester']:
     try:
         from pytest_embedded_idf import CaseTester, IdfDut
     except ImportError:
@@ -1242,7 +1222,6 @@ def pytest_configure(config: Config) -> None:
         parallel_index=config.getoption('parallel_index'),
         check_duplicates=config.getoption('check_duplicates', False),
         prettify_junit_report=_str_bool(config.getoption('prettify_junit_report', False)),
-        add_target_as_marker=_str_bool(config.getoption('add_target_as_marker', False)),
         add_target_as_marker_with_amount=_str_bool(config.getoption('add_target_as_marker_with_amount', False)),
     )
     config.pluginmanager.register(config.stash[_pytest_embedded_key])
@@ -1263,14 +1242,12 @@ class PytestEmbedded:
         parallel_index: int = 1,
         check_duplicates: bool = False,
         prettify_junit_report: bool = False,
-        add_target_as_marker: bool = False,
         add_target_as_marker_with_amount: bool = False,
     ):
         self.parallel_count = parallel_count
         self.parallel_index = parallel_index
         self.check_duplicates = check_duplicates
         self.prettify_junit_report = prettify_junit_report
-        self.add_target_as_marker = add_target_as_marker
         self.add_target_as_marker_with_amount = add_target_as_marker_with_amount
 
     @staticmethod
@@ -1287,7 +1264,7 @@ class PytestEmbedded:
             raise AssertionError('Unity test failed')
 
     @staticmethod
-    def _duplicate_items(items: t.List[_T]) -> t.List[_T]:
+    def _duplicate_items(items: list[_T]) -> list[_T]:
         duplicates = []
         counter = Counter(items)
         for elem, cnt in counter.items():
@@ -1306,9 +1283,9 @@ class PytestEmbedded:
         return item.callspec.params.get(key, default) or default
 
     @pytest.hookimpl(hookwrapper=True, trylast=True)
-    def pytest_collection_modifyitems(self, config: Config, items: t.List[Function]):
+    def pytest_collection_modifyitems(self, config: Config, items: list[Function]):
         # ------ add marker based on target ------
-        if self.add_target_as_marker_with_amount or self.add_target_as_marker:
+        if self.add_target_as_marker_with_amount:
             for item in items:
                 item_target = self.get_param(item, 'target')
                 if not item_target:
@@ -1319,10 +1296,7 @@ class PytestEmbedded:
 
                 # --add-target-as-marker-with-amount
                 count = self.get_param(item, 'count', 1)
-                if self.add_target_as_marker_with_amount:
-                    _marker = targets_to_marker(to_list(parse_multi_dut_args(count, item_target)))
-                if self.add_target_as_marker:
-                    _marker = '-'.join(to_list(parse_multi_dut_args(count, item_target)))
+                _marker = targets_to_marker(to_list(parse_multi_dut_args(count, item_target)))
 
                 item.add_marker(_marker)
 
@@ -1398,18 +1372,10 @@ class PytestEmbedded:
 
     @pytest.hookimpl(trylast=True)
     def pytest_runtest_call(self, item: Function):
-        all_duts: list[Dut] = []
-
-        # Check DUTs created by fixture
+        # raise dut failed cases
         if 'dut' in item.funcargs:
-            fixture_duts = [dut for dut in to_list(item.funcargs['dut']) if isinstance(dut, Dut)]
-            all_duts.extend(fixture_duts)
-
-        # Check DUTs created by DutFactory
-        factory_duts = DutFactory.get_all_duts()
-        all_duts.extend(factory_duts)
-
-        self._raise_dut_failed_cases_if_exists(all_duts)  # type: ignore
+            duts = [dut for dut in to_list(item.funcargs['dut']) if isinstance(dut, Dut)]
+            self._raise_dut_failed_cases_if_exists(duts)  # type: ignore
 
     @pytest.hookimpl(trylast=True)  # combine all possible junit reports should be the last step
     def pytest_sessionfinish(self, session: Session, exitstatus: int) -> None:
